@@ -27,7 +27,7 @@ void DayHistory::showInfo(QModelIndex index)
 
 
     hiw = new HistoryInfoWindow(this);
-    hiw->load(name,group);
+    hiw->load(name,group, currentDate);
     hiw->show();
 }
 
@@ -35,6 +35,8 @@ void DayHistory::load(QString date)
 {
     QList <QString> tmp;
     QString name, group;
+
+    date = currentDate;
     setWindowTitle(date);
     model->clear();
     exercises = xml->getHistoryByDate(date);
