@@ -11,7 +11,7 @@ class HistoryInfoWindow : public QMainWindow
 
 public:
     explicit HistoryInfoWindow(QWidget *parent = 0);
-    void load(QString name, QString group);
+    void load(QString name, QString group, QString date);
 
 private:
     XML *xml;
