@@ -182,7 +182,6 @@ void ListWindow::showContextMenuForWidget(const QPoint &pos)
     QAction *deleteItemAction = new QAction("Remove", this);
     if(group != "Program")
     {
-
         QAction *exportAction = new QAction("Export",this);
         connect(exportAction,SIGNAL(triggered()),this, SLOT(showExport()));
         contextMenu.addAction(exportAction);
@@ -200,7 +199,7 @@ void ListWindow::showContextMenuForWidget(const QPoint &pos)
 void ListWindow::deleteItem()
 {
     QString str;
-
+    qDebug() << "ListWindow::deleteItem 1";
     str = lstExercises->currentIndex().data().toString();
 
     for(int i = 0; i < model->rowCount();i++)
@@ -208,21 +207,32 @@ void ListWindow::deleteItem()
         if(model->index(i,0).data().toString() == str)
             model->removeRow(i);
     }
-
+    qDebug() << "ListWindow::deleteItem 2";
     QMessageBox msgBox;
      msgBox.setText("Do you really want to remove " + str);
      msgBox.setStandardButtons(QMessageBox::Ok | QMessageBox::Cancel);
      msgBox.setDefaultButton(QMessageBox::Cancel);
      int ret = msgBox.exec();
-
+    qDebug() << "ListWindow::deleteItem 3";
      if(ret == QMessageBox::Ok)
      {
+
+         qDebug() << "ListWindow::deleteItem 4";
          if(group != "Cardio" && group != "Program")
-            xml->removeElement(str,"exercises");
+         {
+             qDebug() << "ListWindow::deleteItem 5";
+             xml->removeElement(str,"exercises");
+         }
          else if(group == "Cardio")
-            xml->removeElement(str,"cardio");
+         {
+             qDebug() << "ListWindow::deleteItem 6";
+             xml->removeElement(str,"cardio");
+         }
          else if (group == "Program")
+         {
+             qDebug() << "ListWindow::deleteItem 7";
              xml->removeProgram(str);
+         }
      }
 }
 
@@ -231,19 +241,25 @@ void ListWindow::editItem()
     QString str;
     QList <QString> list;
     str = lstExercises->currentIndex().data().toString();
-
+    qDebug() << "ListWindow::editItem 1";
     if(group == "Program")
     {
         list = xml->loadProgram(str);
+        qDebug() << "ListWindow::editItem 2";
         npw = new NewProgramWindow(this);
+        qDebug() << "ListWindow::editItem 3";
         npw->load(str,list);
         npw->show();
+        qDebug() << "ListWindow::editItem 4";
     }
     else
     {
         list = xml->openEx(str);
+        qDebug() << "ListWindow::editItem 5";
         nw = new NewExerciseWindow(this);
+        qDebug() << "ListWindow::editItem 6";
         nw->load(list.takeFirst(),list.takeFirst(),list.takeFirst(),list.takeFirst());
+        qDebug() << "ListWindow::editItem 7";
         nw->show();
     }
 }
