@@ -12,7 +12,7 @@ class WeightDialog : public QDialog
 
 public:
     explicit WeightDialog(QWidget *parent = 0);
-    void load(QString name, QString grp, QString currentReps);
+    void load(QString name, QString grp, QString currentSet);
     void loadCardio(QString name, QString m, QString s);
 
 signals:
