@@ -69,11 +69,11 @@ void XML::removeProgram(QString name)
     QDomDocument doc( "Program" );
     QString str = "/home/user/.qexercise";
     QFile file( str + "/program.xml" );
-    if( !file.open( QIODevice::ReadOnly ) )
+    if( !file.open( QIODevice::ReadWrite ) )
     {
         return;
     }
-
+    qDebug() << "XML::removeProgram 1";
     doc.setContent(&file);
     file.close();
 
@@ -82,7 +82,7 @@ void XML::removeProgram(QString name)
     {
       return;
     }
-
+    qDebug() << "XML::removeProgram 2";
     QDomNode n = root.firstChild();
     while( !n.isNull() )
     {
@@ -95,11 +95,18 @@ void XML::removeProgram(QString name)
             if(name == e.attribute( "name", "" ))
             {
                 root.removeChild(n);
+                qDebug() << "XML::removeProgram 3";
             }
         }
       }
       n = n.nextSibling();
    }
+    if( !file.open( QIODevice::WriteOnly ) )
+      return;
+    QTextStream ts( &file );
+    ts << doc.toString();
+
+    file.close();
 }
 
 void XML::saveProgram(QString name, QModelIndexList exercises)
@@ -415,10 +422,9 @@ void XML::updateHistory(QString name, QString set, QString kg, QString reps, QSt
     return;
 }
 
-QList <QString> XML::getHistoryByExercise(QString name)
+QList <QString> XML::getHistoryByExercise(QString name, QString date)
 {
     QList <QString> readInfo;
-    QString lastDate;
     QString j;
 
     QDomDocument doc( "Exercises" );
@@ -444,12 +450,12 @@ QList <QString> XML::getHistoryByExercise(QString name)
       {
         if( e.tagName() == "exercise" )
         {
-            if(e.attribute("name", "") == name && lastDate == "")
+            if(e.attribute("name", "") == name && date == "0")
             {
-                lastDate = e.attribute("date", "");
+                date = e.attribute("date", "");
             }
 
-            if(e.attribute("name", "") == name && e.attribute("date", "") == lastDate)
+            if(e.attribute("name", "") == name && e.attribute("date", "") == date)
             {
                 for(int i = 1; i < 10; i++)
                 {
