@@ -36,7 +36,7 @@ public:
     QList< QList <QString> > readHistory();
     QList <QString> getDates();
     QList < QList<QString> > getHistoryByDate(QString date);
-    QList<QString> getHistoryByExercise(QString name);
+    QList<QString> getHistoryByExercise(QString name, QString date = "0");
 
     void saveFood(QString name, QString type, QString kcal, QString protein, QString carbohydrate, QString fat);
     QList<QString> openIngredients();
